@@ -1,5 +1,6 @@
-from arkdata.database.cusor import sqlalchemy
+from arkdata.database.cursor import sqlalchemy, app
 from sqlalchemy import Integer, Column
+from sqlalchemy.sql import text
 import json
 from pathlib import Path
 
@@ -9,7 +10,8 @@ class Table:
 
     @classmethod
     def all(cls):
-        return sqlalchemy.db.session.query(cls).all()
+        with app.app_context():
+            return sqlalchemy.db.session.query(cls).all()
 
     @classmethod
     def find_by(cls, **kwargs):
@@ -38,7 +40,7 @@ class Table:
         return sqlalchemy.db.session.query(cls).count()
 
     @classmethod
-    def bulk_insert(cls, values: list[dict]):
+    def bulk_insert(cls, values: list):
         bulk = []
         for items in values:
             item = cls(**items)
@@ -49,27 +51,30 @@ class Table:
 
     @classmethod
     def drop_table(cls):
-        cls.commit()
-        inspector = sqlalchemy.db.inspect(sqlalchemy.db.engine)
-        if inspector.has_table(cls.__tablename__):
-            sqlalchemy.db.session.execute(f'DROP TABLE {cls.__tablename__}')
+        with app.app_context():
+            inspector = sqlalchemy.db.inspect(sqlalchemy.db.engine)
+            if inspector.has_table(cls.__tablename__):
+                sqlalchemy.db.session.execute(text(f'DROP TABLE {cls.__tablename__}'))
 
     @classmethod
     def create_table(cls):
-        inspector = sqlalchemy.db.inspect(sqlalchemy.db.engine)
-        if not inspector.has_table(cls.__tablename__):
-            cls.__table__.create(sqlalchemy.db.session.bind, checkfirst=True)
+        with app.app_context():
+            inspector = sqlalchemy.db.inspect(sqlalchemy.db.engine)
+            if not inspector.has_table(cls.__tablename__):
+                cls.__table__.create(sqlalchemy.db.session.bind, checkfirst=True)
 
     @classmethod
     def clear_table(cls):
-        inspector = sqlalchemy.db.inspect(sqlalchemy.db.engine)
-        if inspector.has_table(cls.__tablename__):
-            sqlalchemy.db.session.execute(f'TRUNCATE TABLE {cls.__tablename__}')
+        with app.app_context():
+            inspector = sqlalchemy.db.inspect(sqlalchemy.db.engine)
+            if inspector.has_table(cls.__tablename__):
+                sqlalchemy.db.session.execute(text(f'TRUNCATE TABLE {cls.__tablename__}'))
 
     @classmethod
     def table_exists(cls):
-        inspector = sqlalchemy.db.inspect(sqlalchemy.db.engine)
-        return inspector.has_table(cls.__tablename__)
+        with app.app_context():
+            inspector = sqlalchemy.db.inspect(sqlalchemy.db.engine)
+            return inspector.has_table(cls.__tablename__)
 
     @classmethod
     def _seed_table(cls, path: Path or str):
@@ -104,9 +109,10 @@ class Table:
         self.commit()
 
     def delete(self):
-        sqlalchemy.db.session.delete(self)
+        with app.app_context():
+            sqlalchemy.db.session.delete(self)
 
-    def keys(self) -> list[str]:
+    def keys(self) -> list:
         return self.columns()
 
     def values(self) -> list:
@@ -121,12 +127,13 @@ class Table:
         return getattr(self, key)
 
     def __call__(self, *args, **kwargs):
-        difference = set(kwargs.keys()).difference(set(self.columns()))
-        error_message = f"{difference} are not Columns of '{self.__tablename__}': {self.columns()}"
-        assert len(difference) == 0, error_message
-        for key, val in kwargs.items():
-            setattr(self, key, val)
-        return self
+        with app.app_context():
+            difference = set(kwargs.keys()).difference(set(self.columns()))
+            error_message = f"{difference} are not Columns of '{self.__tablename__}': {self.columns()}"
+            assert len(difference) == 0, error_message
+            for key, val in kwargs.items():
+                setattr(self, key, val)
+            return self
 
     def __str__(self):
         table_name = self.__tablename__.title().replace("_", "")
