@@ -66,6 +66,11 @@ def create_all():
         eval(f'{model}.create_table()')
 
 
+def clear_all():
+    for model in __all__:
+        eval(f'{model}.clear_table()')
+
+
 def drop_all():
     for model in __all__:
         eval(f'{model}.drop_table()')
