@@ -1,4 +1,4 @@
-from arkdata.database.cusor import sqlalchemy
+from arkdata.database.cursor import sqlalchemy
 from arkdata.database.table import Table
 from datetime import datetime
 from sqlalchemy import Column, String, Integer, Boolean, DateTime
@@ -22,7 +22,7 @@ class OrderItem(sqlalchemy.db.Model, Table):
         self.date = date
 
     @classmethod
-    def ship(cls, orders: list['OrderItem']):
+    def ship(cls, orders: list):
         for order in orders:
             order.delivered = True
         cls.commit()
