@@ -1,4 +1,4 @@
-from arkdata.database.cusor import sqlalchemy
+from arkdata.database.cursor import sqlalchemy
 from arkdata.database.table import Table
 from arkdata import models
 from sqlalchemy import Column, String, Integer, Text
