@@ -1,5 +1,5 @@
 from sqlalchemy import Column, String
-from arkdata.database.cusor import sqlalchemy
+from arkdata.database.cursor import sqlalchemy
 from arkdata.database.table import Table
 from pathlib import Path
 import os
